@@ -23,15 +23,19 @@ import matplotlib.animation as anim
 
 # ensure that ImageMagick writer is found (and not Windows' convert.exe)
 if platform.system().lower().startswith('windows'):
-    if anim.rcParams['animation.convert_path'].endswith(('convert',
-                                                        'convert.exe')):
-        anim.rcParams['animation.convert_path'] = 'magick'
+    if 'rcParams' in anim.__dir__():
+        rc = anim.rcParams
+    else:
+        rc = matplotlib.rcParams
+
+    if rc['animation.convert_path'].endswith(('convert', 'convert.exe')):
+        rc['animation.convert_path'] = 'magick'
 
 
 class Molecule(object):
     def __init__(self, atoms, scale=0.7, name=None, square=False,
                  colors=None, labels=None, rot_axis=None,
-                 bond_color='white', bond_edgecolor='black',
+                 alphas=None, bond_color='white', bond_edgecolor='black',
                  cb_min=None, cb_max=None, center_data=False, cmap=cm.bwr_r,
                  draw=['atoms', 'bonds']):
         """
@@ -76,6 +80,10 @@ class Molecule(object):
                             e.g. '-z' causes clockwise rotation
                           (Default: 'y')
 
+        - alphas (int iterable dict): set transparency of atom type
+                                      or atom indices
+                                      (Default: None)
+
         - bond_color (str): specify color of bonds
                             (Default: white)
 
@@ -197,8 +205,14 @@ class Molecule(object):
         self.legend = None
         self.leg_order = 'size'
 
+        # alpha value of atoms
+        self._alphas = [1.] * len(self.atoms)
+
+        if alphas is not None:
+            self.alphas = alphas
+
         # color attributes
-        self._colors = None
+        self._colors = [jmol_colors[a.number] for a in self.atoms]
 
         # track if colors have changed
         self._prevcolors = None
@@ -222,6 +236,27 @@ class Molecule(object):
     def __getitem__(self, i):
         return self.atoms[i]
 
+    @property
+    def alphas(self):
+        return self._alphas
+
+    @alphas.setter
+    def alphas(self, value):
+        changed = True
+        if isinstance(value, dict):
+            self._alphas = self._dict_to_list(value, self._alphas)[0]
+        elif ((isinstance(value, list) or isinstance(value, np.ndarray)) and
+              len(value) == len(self)):
+            self._alphas = list(value)
+        elif isinstance(value, int) or isinstance(value, float):
+            self._alphas = [value] * len(self)
+        else:
+            changed = False
+        if changed and self.fig is not None:
+            self.draw_atoms(force=True)
+            if 'bonds' in self.drawn:
+                self.draw_bonds()
+
     # colors getter
     @property
     def colors(self):
@@ -477,6 +512,7 @@ class Molecule(object):
                             (a.x, a.y),
                             radius=self.radii[i],
                             facecolor=self._colors[i],
+                            alpha=self._alphas[i],
                             edgecolor='k',
                             linewidth=self.scaled_borderwidth,
                             zorder=a.z)
@@ -569,14 +605,19 @@ class Molecule(object):
             # use avg z for zorder
             zorder = (xy1[2] + xy2[2]) / 2
 
+            # set alpha value of bond to lowest alpha atom
+            alpha = min(self.alphas[b[0]], self.alphas[b[1]])
+
             if update:
                 # update bond outline
                 self.bond_objs[2 * i].set_data((x, y))
                 self.bond_objs[2 * i].set_zorder(zorder - 0.001)
+                self.bond_objs[2 * i].set_alpha(alpha)
 
                 # update bond
                 self.bond_objs[2 * i + 1].set_data((x, y))
                 self.bond_objs[2 * i + 1].set_zorder(zorder)
+                self.bond_objs[2 * i + 1].set_alpha(alpha)
             else:
                 # draw thinner white line over black line
                 # to create bordered bonds
@@ -586,6 +627,7 @@ class Molecule(object):
                         zorder=zorder - 0.001,
                         color=self.bond_edgecolor,
                         lw=self.scaled_bond_width,
+                        alpha=alpha,
                         solid_capstyle='round')
 
                 # draw bond fill
@@ -594,6 +636,7 @@ class Molecule(object):
                         y,
                         zorder=zorder,
                         color=self.bond_color,
+                        alpha=alpha,
                         lw=self.scaled_bond_fill,
                         solid_capstyle='round')
 
@@ -933,6 +976,27 @@ class Molecule(object):
         # redraw figure
         self.redraw()
 
+    def custom_rotate(self, rot_commands):
+        """
+        Applies an ordered list of rotation commands to molecule
+        - list should have the form [angle1, x|y|z, angle2, x|y|z, ...]
+        - rotations are applied sequentially and different orders will lead
+          to different results
+
+        Args:
+        - rot_commands (list): list of ordered rotation commands to apply
+                               - [angle, (x|y|z), angle, (x|y|z), ...]
+        """
+        # store current rotation axis
+        rot_axis = self.rot_axis
+
+        # apply the rotations sequentially
+        for angle, axis in zip(rot_commands[::2], rot_commands[1::2]):
+            self.rotate(angle, axis)
+
+        # set rotation axis back to original
+        self.rot_axis = rot_axis
+
     def add_param(self, value):
         if value not in self.fig_params:
             self.fig_params.append(value)
@@ -1019,7 +1083,7 @@ class Molecule(object):
             self.rot_axis = 'y'
 
         try:
-            self.atoms.rotate(angle, v=self.rot_axis,
+            self.atoms.rotate(float(angle), v=self.rot_axis,
                               center=(0, 0, 0))
             self.update()
         except Exception:
@@ -1366,24 +1430,16 @@ class Molecule(object):
                 failed = False
             except ValueError:
                 pass
+        # convert dict of color specs
         elif isinstance(value, dict):
-            colors_dict = {k.title(): value[k] for k in value.copy()}
-
-            # find atom types that are not in atoms object
-            not_found = [c for c in colors_dict
-                         if c.title() not in self.atoms.symbols]
-            if not_found:
-                print('%s do not match atom types.' % (', '.join(not_found)))
-
-            # use combination of color_dict and jmol_colors
-            try:
-                self._colors = [mcolors.to_rgba(colors_dict.get(i.symbol,
-                                list(jmol_colors[i.number])))
-                                for i in self.atoms]
-                failed = False
-            except ValueError:
-                pass
+            value, allow_legend = self._dict_to_list(value, self._colors)
+            self.block_legend = not allow_legend
 
+            for i in range(len(value)):
+                if isinstance(value[i], str):
+                    value[i] = list(mcolors.to_rgba(value[i]))[:-1]
+            self._colors = value
+            failed = False
         elif type(value) in [list, np.ndarray]:
             # if values (ex charge), create Red Blue colormap
             try:
@@ -1417,7 +1473,7 @@ class Molecule(object):
                 self.block_colorbar = False
                 failed = False
             # else see if list contains strings
-            except ValueError:
+            except Exception:
                 # if length is the same, try to convert items to valid colors
                 if len(value) == len(self):
                     try:
@@ -1483,3 +1539,57 @@ class Molecule(object):
         # redraw atoms if labels have changed
         if self._labels != old_labels and 'atoms' in self._drawn:
             self.draw_atoms(force=True)
+
+    def _dict_to_list(self, prop_dict, default_ls):
+        """
+        Converts dict of custom properties into array of values for each atom
+        - works for colors and alpha values
+
+        Args:
+        prop_dict (dict): dictionary of properties for certain atoms
+                          - key = chem symbol: all atoms of that symbol
+                          - key = index: just that atom index
+        default_ls (list): default values for atoms in molecule
+
+        Returns:
+        (np.ndarray): 1D array of custom and default values, ordered by atom
+        allow_legend (bool): if True, each atom type has a consistent value
+        """
+        val_ls = copy.deepcopy(default_ls)
+
+        # track or properties are consistant for each atom type
+        allow_legend = True
+
+        # track values for each atom type if consistent
+        const_val_dict = {}
+
+        arr = np.array(val_ls)
+        # see if items are iterable (i.e. arr is larger than 1D)
+        nd = len(arr.shape) > 1
+
+        for s in set(self.atoms.symbols):
+            uniq = np.unique(arr[self.atoms.symbols == s], axis=0)
+            if len(uniq) > 1:
+                allow_legend = False
+                break
+            const_val_dict[s] = uniq.tolist()[0]
+
+        # iterate over symbols first, then atom indices
+        for k in sorted(prop_dict, key=lambda i: [not isinstance(i, str), i]):
+            # if chemical symbol or R (equivalent to C and H)
+            if isinstance(k, str) and (k.title() in chemical_symbols or
+               k.upper() == 'R'):
+                # find C and H atoms
+                if k.upper() == 'R':
+                    inds = np.where(np.isin(self.atoms.symbols, ['C', 'H']))[0]
+                else:
+                    inds = np.where(self.atoms.symbols == k.title())[0]
+                for i in inds:
+                    val_ls[i] = prop_dict[k]
+            elif ((isinstance(k, int) or str(k).isdigit()) and
+                  (-1 < int(k) < len(val_ls))):
+                val_ls[int(k)] = prop_dict[k]
+                if prop_dict[k] != const_val_dict[self.atoms.symbols[int(k)]]:
+                    allow_legend = False
+
+        return val_ls, allow_legend
